pub async fn run_server() -> Result<()>Expand description
Runs the Maze Web Server, which hosts the Maze Web API. This uses actix to serve the API and
utoipa to publish it as an OpenAPI-compliant interface
for use in third party products such as Swagger. In addition, the server also publishes its own
Swagger-related endpoints that can be used to manually test the API in user-friendly web pages (e.g. /api-docs/v1/swagger-ui/).